@@ -57,11 +57,16 @@ char * EXPORT_CALL lou_getProgramPath (void);
     compbrlAtCursor = 2,
     dotsIO = 4,
     comp8Dots = 8,
-    pass1Only = 16
+    pass1Only = 16,
+    compbrlLeftCursor = 32
   } translationModes;
 
 char * EXPORT_CALL lou_version ();
 
+int EXPORT_CALL lou_charSize ();
+
+/* Return the size of widechar */
+
   int EXPORT_CALL lou_translateString
     (const char *trantab,
      const widechar *inbuf,
@@ -77,7 +82,11 @@ char * EXPORT_CALL lou_version ();
 int EXPORT_CALL lou_hyphenate (const char *trantab, const widechar
 	       *inbuf,
       int inlen, char *hyphens, int mode);
-
+int EXPORT_CALL lou_dotsToChar (const char *trantab, widechar *inbuf, 
+      widechar *outbuf, int length);
+int EXPORT_CALL lou_charToDots (const char *trantab, const widechar 
+*inbuf, 
+      widechar *outbuf, int length);
    int EXPORT_CALL lou_backTranslateString (const char *trantab,
 			       const widechar *inbuf,
 			       int *inlen,
@@ -106,10 +115,12 @@ char *typeform, char *spacing, int
   void * EXPORT_CALL lou_getTable (const char *trantab);
 /* This function checks a table for errors. If none are found it loads 
 * the table into memory and returns a pointer to it. if errors are found 
-* it returns a null pointer. It is called by _ou_translateString and 
+* it returns a null pointer. It is called by lou_translateString and 
 * lou_backTranslateString and also by functions in liblouisxml
 */
 
+int EXPORT_CALL lou_compileString (const char *tableList, const char 
+    *inString);
   void EXPORT_CALL lou_free (void);
 /* This function should be called at the end of 
 * the application to free all memory allocated by liblouis. */
@@ -117,5 +128,4 @@ char *typeform, char *spacing, int
 #ifdef __cplusplus
 }
 #endif				/* __cplusplus */
-
 #endif				/*LibLOUIS_H_ */
