@@ -401,7 +401,6 @@ for_updatePositions (const widechar * outChars, int inLength, int outLength)
 	{
 	  if (src >= compbrlStart)
 	    {
-	      cursorPosition = dest + cursorPosition - compbrlStart;
 	      cursorStatus = 2;
 	      return (doCompTrans (compbrlStart, compbrlEnd));
 	    }
@@ -418,6 +417,8 @@ for_updatePositions (const widechar * outChars, int inLength, int outLength)
 	  cursorStatus = 1;
 	}
     }
+  else if (cursorStatus == 2 && cursorPosition == src)
+    cursorPosition = dest;
   if (inputPositions != NULL || outputPositions != NULL)
     {
       if (outLength <= inLength)
@@ -1539,11 +1540,28 @@ undefinedCharacter (widechar c)
 {
 /*Display an undefined character in the output buffer*/
   int k;
-  char *display = showString (&c, 1);
+  char *display;
+  if (table->undefined)
+    {
+      TranslationTableRule *transRule = (TranslationTableRule *)
+	& table->ruleArea[table->undefined];
+      if (!for_updatePositions
+	  (&transRule->charsdots[transRule->charslen],
+	   transRule->charslen, transRule->dotslen))
+	return 0;
+      return 1;
+    }
+  display = showString (&c, 1);
   if ((dest + strlen (display)) > destmax)
     return 0;
+  if (outputPositions != NULL)
+    outputPositions[srcMapping[src]] = dest;
   for (k = 0; k < strlen (display); k++)
-    currentOutput[dest++] = getDotsForChar (display[k]);
+    {
+      if (inputPositions != NULL)
+	inputPositions[dest] = srcMapping[src];
+      currentOutput[dest++] = getDotsForChar (display[k]);
+    }
   return 1;
 }
 
